@@ -1,5 +1,5 @@
 # fetchcode is a free software tool from nexB Inc. and others.
-# Visit https://github.com/nexB/fetchcode for support and download.
+# Visit https://github.com/aboutcode-org/fetchcode for support and download.
 #
 # Copyright (c) nexB Inc. and others. All rights reserved.
 # http://nexb.com and http://aboutcode.org
@@ -28,12 +28,18 @@ def obtain(dest, url):
 @pytest.mark.parametrize(
     "url, vcs_type, domain",
     [
-        pytest.param("git+http://github.com/jamesor/mongoose-versioner", "git", "github.com", id="git_http"),
-        pytest.param("git://github.com/jamesor/mongoose-versioner", "git", "github.com", id="git"),
-        pytest.param("git+https://github.com/jamesor/mongoose-versioner", "git", "github.com", id="git_https"),
-        pytest.param("git+ssh://github.com/jamesor/mongoose-versioner", "git", "github.com", id="git_ssh"),
-        pytest.param("git+file://github.com/jamesor/mongoose-versioner", "git", "github.com", id="git_file"),
-        pytest.param("git+git://github.com/jamesor/mongoose-versioner", "git", "github.com", id="git_git")
+        pytest.param("git+http://github.com/jamesor/mongoose-versioner",
+                     "git", "github.com", id="git_http"),
+        pytest.param("git://github.com/jamesor/mongoose-versioner",
+                     "git", "github.com", id="git"),
+        pytest.param("git+https://github.com/jamesor/mongoose-versioner",
+                     "git", "github.com", id="git_https"),
+        pytest.param("git+ssh://github.com/jamesor/mongoose-versioner",
+                     "git", "github.com", id="git_ssh"),
+        pytest.param("git+file://github.com/jamesor/mongoose-versioner",
+                     "git", "github.com", id="git_file"),
+        pytest.param("git+git://github.com/jamesor/mongoose-versioner",
+                     "git", "github.com", id="git_git")
     ],
 )
 @mock.patch("fetchcode.vcs.git.vcs.get_backend")
@@ -43,6 +49,7 @@ def test_fetch_via_vcs_returns_response(mock_backend, url, vcs_type, domain):
     assert response.vcs_type == vcs_type
     assert response.domain == domain
 
+
 def test_fetch_with_git_invalid_scheme():
     invalid_urls = [
         "https://github.com/TG1999/fetchcode",
